**neo4django** is an Object Graph Mapper that let's you use familiar Django model definitions and queries against the Neo4j graph database.

The library is tested against Django 1.4.4 and Neo4j versions 1.8.2-1.9M04. Docs are on `ReadTheDocs <https://neo4django.readthedocs.org/en/latest/>`_.

.. image:: https://secure.travis-ci.org/scholrly/neo4django.png?branch=master

Installation
============

Using pip, you can install from PyPi::

    pip install neo4django

or straight from GitHub::

    pip install -e git+https://github.com/scholrly/neo4django/#egg=neo4django

Documentation
=============

Detailed documentation can be found in the docs folder or on `ReadTheDocs <https://neo4django.readthedocs.org/en/latest/>`_.
